@@ -1,10 +1,10 @@
 /*--------------------------------------------------------------------
- *	$Id: grdraster.c,v 1.36 2006/10/24 16:07:04 remko Exp $
+ *	$Id: grdraster.c,v 1.56 2009/01/09 04:02:35 guru Exp $
  *
- *    Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
-/* grdraster.c -- read a rasterfile and extract a region as a grdfile.
+/* grdraster.c -- read a rasterfile and extract a region as a grid file.
  *
  * This is a complete rewrite for GMT version 3.0.  This is based on
  * the earlier versions written by me for installations at Scripps and
@@ -13,7 +13,7 @@
  *
  * Author:	Walter H. F. Smith
  * Date:	20 January, 1995
- * Update:	10 March 1999 PW: Now use new default dir $GMTHOME/share/dbase
+ * Update:	10 March 1999 PW: Now use new default dir $GMT_SHAREDIR/dbase
  *		05 April 1999 PW: Now deals with DOS/UNIX directory signs
  *		07 April 1999 PW: ...and DOS drive letters.
  *		27 April 1999 PW: Added option to swap via #define GMTSWAP
@@ -34,13 +34,24 @@
 
 #include "gmt.h"
 
+struct GRDRASTER_CTRL {
+	struct G {	/* -G<output_grdfile> */
+		BOOLEAN active;
+		char *file;
+	} G;
+	struct I {	/* -Idx[/dy] */
+		BOOLEAN active;
+		double xinc, yinc;
+	} I;
+};
+
 struct GRDRASTER_INFO {
 	struct GRD_HEADER h;
-	int	id;		/* File number  */
-	int	nglobal;	/* If not 0, ras is global and i%nglobal makes it periodic  */
-	int	nanflag;
-	int	nanset;		/* True if raster uses nanflag to signal NaN  */
-	int	skip;		/* Skip this number of header bytes when opeing file  */
+	GMT_LONG	id;		/* File number  */
+	GMT_LONG	nglobal;	/* If not 0, ras is global and i%nglobal makes it periodic  */
+	GMT_LONG	nanflag;
+	GMT_LONG	nanset;		/* True if raster uses nanflag to signal NaN  */
+	GMT_LONG	skip;		/* Skip this number of header bytes when opening file  */
 	char	type;
 	BOOLEAN swap_me;	/* TRUE if data set need to be swapped */
 	BOOLEAN geo;		/* TRUE if we believe x/y is lon/lat, FALSE otherwise */
@@ -55,13 +66,13 @@ int main (int argc, char **argv)
 #else
 	char my_endian = 'B';	/* This machine is Big endian */
 #endif
-	char	*grdfilename, *buffer = NULL, *r_opt = NULL, *tselect = CNULL, match[GRD_REMARK_LEN];
+	char	*buffer = NULL, *r_opt = NULL, *tselect = CNULL, match[GRD_REMARK_LEN];
 	unsigned char *ubuffer = NULL;
 	static unsigned char maskset[8] = {128, 64, 32, 16, 8, 4, 2, 1};
 	
-	int	i, j, k, ksize = 0, iselect, nselected, imult, jmult, nrasters, ij_offset;
-	int	irasstart, jrasstart, n_nan, iras, jras, ij, ijras, jseek, nmask = 0;
-	int	error, incset, firstread;
+	GMT_LONG	i, j, k, ksize = 0, iselect, nselected = 0, imult, jmult, nrasters, ij_offset;
+	GMT_LONG	irasstart, jrasstart, n_nan, iras, jras, ij, ijras, jseek, nmask = 0;
+	GMT_LONG	error = FALSE, firstread, nm;
 	
 	float	*grd = NULL, *floatrasrow = NULL;
 	
@@ -75,18 +86,20 @@ int main (int argc, char **argv)
 
 	FILE *fp;
 
+	struct GRDRASTER_CTRL *Ctrl;
+	
+	void *New_Grdraster_Ctrl (), Free_Grdraster_Ctrl (struct GRDRASTER_CTRL *C);
 	void convert_u_row (struct GRDRASTER_INFO ras, float *row, unsigned char *buffer);
 	void convert_c_row (struct GRDRASTER_INFO ras, float *row, char *buffer);
 	void convert_d_row (struct GRDRASTER_INFO ras, float *row, short unsigned int *buffer);
 	void convert_i_row (struct GRDRASTER_INFO ras, float *row, short int *buffer);
 	void convert_l_row (struct GRDRASTER_INFO ras, float *row, int *buffer);
-	int load_rasinfo (struct GRDRASTER_INFO **rasinfo, char endian);
+	GMT_LONG load_rasinfo (struct GRDRASTER_INFO **rasinfo, char endian);
 
 	argc = GMT_begin (argc, argv);
 
-	nselected = 0;
-	error = incset = FALSE;
-	grdfilename = CNULL;
+	Ctrl = (struct GRDRASTER_CTRL *)New_Grdraster_Ctrl ();	/* Allocate and initialize a new control structure */
+
 	GMT_grd_init (&h, argc, argv, FALSE);
 
 	if (!(nrasters = load_rasinfo(&rasinfo, my_endian))) {
@@ -111,11 +124,15 @@ int main (int argc, char **argv)
 					error += GMT_parse_b_option (&argv[i][2]);
 					break;
 				case 'G':
-					grdfilename = &argv[i][2];
+					Ctrl->G.active = TRUE;
+					Ctrl->G.file = strdup (&argv[i][2]);
 					break;
 				case 'I':
-					error += GMT_getinc(&argv[i][2], &h.x_inc, &h.y_inc);
-					incset = TRUE;
+					Ctrl->I.active = TRUE;
+					if (GMT_getinc (&argv[i][2], &Ctrl->I.xinc, &Ctrl->I.yinc)) {
+						GMT_inc_syntax ('I', 1);
+						error = TRUE;
+					}
 					break;
 				default:
 					error = TRUE;
@@ -129,7 +146,7 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr, "grdraster %s - Extract a region from a raster and save in a grdfile\n\n", GMT_VERSION);
+		fprintf (stderr, "grdraster %s - Extract a region from a raster and save in a grid file\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdraster <file number>|<text> %s [-G<grdfilename>] [%s]\n", GMT_Rgeo_OPT, GMT_Id_OPT);
 		fprintf (stderr, " [%s]\n", GMT_bo_OPT);
 
@@ -164,17 +181,19 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
+	GMT_check_lattice (&Ctrl->I.xinc, &Ctrl->I.yinc, NULL, &Ctrl->I.active);
+
 	/* Check that arguments were valid:  */
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
 		error++;
 	}
-	if (incset && (h.x_inc <= 0.0 || h.y_inc <= 0.0) ) {
+	if (Ctrl->I.active && (Ctrl->I.xinc <= 0.0 || Ctrl->I.yinc <= 0.0) ) {
                 fprintf (stderr, "%s: GMT SYNTAX ERROR -I option.  Must specify positive increment(s)\n", GMT_program);
                 error++;
         }
-        if (!grdfilename) {
-                if (gmtdefs.verbose) fprintf (stderr, "%s: No grdfile given - will write xyz to stdout\n", GMT_program);
+        if (!Ctrl->G.file) {
+                if (gmtdefs.verbose) fprintf (stderr, "%s: No grid file given - will write xyz to stdout\n", GMT_program);
                 xyz_out = TRUE;
         }
 	if (nselected != 1) {
@@ -213,7 +232,7 @@ int main (int argc, char **argv)
 		}
 		if (j == -1) {
 			if (iselect != -1)
-				fprintf (stderr, "%s ERROR:  No raster with file number %d in grdraster.info\n", GMT_program, iselect);
+				fprintf (stderr, "%s ERROR:  No raster with file number %ld in grdraster.info\n", GMT_program, iselect);
 			else
 				fprintf (stderr, "%s ERROR:  No raster with text %s in grdraster.info\n", GMT_program, tselect);
 			error++;
@@ -224,13 +243,13 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	GMT_io.in_col_type[0] = GMT_io.out_col_type[0] = (myras.geo) ? GMT_IS_LON : GMT_IS_FLOAT;
 	GMT_io.in_col_type[1] = GMT_io.out_col_type[1] = (myras.geo) ? GMT_IS_LAT : GMT_IS_FLOAT;
 
-	/* Everything looks OK so far.  If (incset) verify that it will work, else set it.  */
-	if (incset) {
+	/* Everything looks OK so far.  If (Ctrl->I.active) verify that it will work, else set it.  */
+	if (Ctrl->I.active) {
+		h.x_inc = Ctrl->I.xinc;
+		h.y_inc = Ctrl->I.yinc;
 		tol = 0.01 * myras.h.x_inc;
 		imult = irint(h.x_inc / myras.h.x_inc);
 		if (imult < 1 || fabs(h.x_inc - imult * myras.h.x_inc) > tol) error++;
@@ -249,9 +268,9 @@ int main (int argc, char **argv)
 		imult = jmult = 1;
 	}
 
-	if (!project_info.region && project_info.projection >= 0) {
+	if (!project_info.region && project_info.projection != GMT_NO_PROJ) {
 	
-		GMT_map_setup (h.x_min, h.x_max, h.y_min, h.y_max);
+		GMT_err_fail (GMT_map_setup (h.x_min, h.x_max, h.y_min, h.y_max), "");
 		
 		h.x_min = floor (project_info.w / h.x_inc) * h.x_inc;
 		h.x_max = ceil (project_info.e / h.x_inc) * h.x_inc;
@@ -259,13 +278,13 @@ int main (int argc, char **argv)
 		h.y_max = ceil (project_info.n / h.y_inc) * h.y_inc;
 		
 		if (gmtdefs.verbose && rint (h.x_inc * 60.0) == (h.x_inc * 60.0)) {	/* Spacing in even minutes */
-			int w, e, s, n, wm, em, sm, nm;
+			GMT_LONG w, e, s, n, wm, em, sm, nm;
 			
-			w = (int) floor (h.x_min);	wm = irint ((h.x_min - w) * 60.0);
-			e = (int) floor (h.x_max);	em = irint ((h.x_max - e) * 60.0);
-			s = (int) floor (h.y_min);	sm = irint ((h.y_min - s) * 60.0);
-			n = (int) floor (h.y_max);	nm = irint ((h.y_max - n) * 60.0);
-			fprintf (stderr, "%s: %s -> -R%d:%2.2d/%d:%2.2d/%d:%2.2d/%d:%2.2d\n", GMT_program, r_opt, w, wm, e, em, s, sm, n, nm);
+			w = (GMT_LONG) floor (h.x_min);	wm = (GMT_LONG) irint ((h.x_min - w) * 60.0);
+			e = (GMT_LONG) floor (h.x_max);	em = (GMT_LONG) irint ((h.x_max - e) * 60.0);
+			s = (GMT_LONG) floor (h.y_min);	sm = (GMT_LONG) irint ((h.y_min - s) * 60.0);
+			n = (GMT_LONG) floor (h.y_max);	nm = (GMT_LONG) irint ((h.y_max - n) * 60.0);
+			fprintf (stderr, "%s: %s -> -R%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld\n", GMT_program, r_opt, w, wm, e, em, s, sm, n, nm);
 		}
 		else if (gmtdefs.verbose)
 			fprintf (stderr, "%s: %s -> -R%g/%g/%g/%g\n", GMT_program, r_opt, h.x_min, h.x_max, h.y_min, h.y_max);
@@ -286,16 +305,16 @@ int main (int argc, char **argv)
 		h.nx = irint ((h.x_max - h.x_min) / h.x_inc);
 		h.ny = irint ((h.y_max - h.y_min) / h.y_inc);
 		fprintf(stderr, "%s WARNING:  Your -R option does not create a region divisible by x_inc, y_inc.\n", GMT_program);
-		if (fabs (rint (h.x_inc * 60.0) - h.x_inc * 60.0) < GMT_CONV_LIMIT) {	/* Spacing in even minutes */
-			int w, e, s, n, wm, em, sm, nm;
-			w = (int) floor (h.x_min);	wm = irint ((h.x_min - w) * 60.0);
-			e = (int) floor (h.x_max);	em = irint ((h.x_max - e) * 60.0);
-			s = (int) floor (h.y_min);	sm = irint ((h.y_min - s) * 60.0);
-			n = (int) floor (h.y_max);	nm = irint ((h.y_max - n) * 60.0);
+		if (GMT_IS_ZERO (rint (h.x_inc * 60.0) - h.x_inc * 60.0)) {	/* Spacing in even minutes */
+			GMT_LONG w, e, s, n, wm, em, sm, nm;
+			w = (GMT_LONG) floor (h.x_min);	wm = (GMT_LONG) irint ((h.x_min - w) * 60.0);
+			e = (GMT_LONG) floor (h.x_max);	em = (GMT_LONG) irint ((h.x_max - e) * 60.0);
+			s = (GMT_LONG) floor (h.y_min);	sm = (GMT_LONG) irint ((h.y_min - s) * 60.0);
+			n = (GMT_LONG) floor (h.y_max);	nm = (GMT_LONG) irint ((h.y_max - n) * 60.0);
 			if (project_info.region)
-				fprintf(stderr, "%s WARNING:  Region reset to -R%d:%2.2d/%d:%2.2d/%d:%2.2d/%d:%2.2d.\n", GMT_program, w, wm, e, em, s, sm, n, nm);
+				fprintf(stderr, "%s WARNING:  Region reset to -R%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld.\n", GMT_program, w, wm, e, em, s, sm, n, nm);
 			else
-				fprintf(stderr, "%s WARNING:  Region reset to -R%d:%2.2d/%d:%2.2d/%d:%2.2d/%d:%2.2dr\n", GMT_program, w, wm, s, sm, e, em, n, nm);
+				fprintf(stderr, "%s WARNING:  Region reset to -R%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ld/%ld:%2.2ldr\n", GMT_program, w, wm, s, sm, e, em, n, nm);
 		}
 		else {
 			if (project_info.region)
@@ -344,13 +363,14 @@ int main (int argc, char **argv)
 		for (i = 0; i < h.nx; i++) x[i] = GMT_i_to_x (i, h.x_min, h.x_max, h.x_inc, h.xy_off, h.nx);
 		ij_offset = 0;
 	} else {	/* Need entire grid */
-		grd = (float *)GMT_memory(VNULL, (size_t)(h.nx*h.ny), sizeof(float), GMT_program);
+		nm = GMT_get_nm (h.nx, h.ny);
+		grd = (float *)GMT_memory(VNULL, (size_t)nm, sizeof(float), GMT_program);
 		ij_offset = h.nx;
 	}
 	
 	if (myras.type == 'b') {
 		/* Need to read the whole thing:  */
-		nmask = (int)ceil (myras.h.nx * myras.h.ny * 0.125);
+		nmask = (GMT_LONG)ceil (myras.h.nx * myras.h.ny * 0.125);
 		ubuffer = (unsigned char *)GMT_memory(VNULL, (size_t)nmask, (size_t)1, GMT_program);
 	}
 	else {
@@ -380,7 +400,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 	if (myras.skip && fseek (fp, (long) (myras.skip), SEEK_CUR) ) {
-		fprintf(stderr,"%s ERROR skipping %d bytes in %s.\n", GMT_program, myras.skip, myras.h.remark);
+		fprintf(stderr,"%s ERROR skipping %ld bytes in %s.\n", GMT_program, myras.skip, myras.h.remark);
 		exit (EXIT_FAILURE);
 	}
 	if (gmtdefs.verbose) fprintf(stderr, "%s:  Reading from raster %s\n", GMT_program, myras.h.remark);
@@ -464,7 +484,7 @@ int main (int argc, char **argv)
 					exit (EXIT_FAILURE);
 				}
 #ifdef DEBUG
-				fprintf (stderr, "%s: Doing line %6.6d\r", GMT_program, j);
+				fprintf (stderr, "%s: Doing line %6.6ld\r", GMT_program, j);
 #endif
 				switch (myras.type) {
 					case 'u':
@@ -513,19 +533,21 @@ int main (int argc, char **argv)
 	fclose(fp);
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s:  Finished reading from %s\n", GMT_program, myras.h.remark);
-	if (gmtdefs.verbose) fprintf (stderr, "%s:  min max and # NaN found: %g %g %d\n", GMT_program, h.z_min, h.z_max, n_nan);
+	if (gmtdefs.verbose) fprintf (stderr, "%s:  min max and # NaN found: %g %g %ld\n", GMT_program, h.z_min, h.z_max, n_nan);
 
-	if (n_nan == h.nx * h.ny) fprintf(stderr,"%s: WARNING - Your grd file is entirely full of NaNs.\n", GMT_program);
+	if (n_nan == h.nx * h.ny) fprintf(stderr,"%s: WARNING - Your grid file is entirely full of NaNs.\n", GMT_program);
 
 	if (xyz_out) {
 		GMT_free ((void *)x);
 	}
 	else
-		GMT_write_grd (grdfilename, &h, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &h, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 		
 	GMT_free ((void *)grd);
 	GMT_free ((void *)rasinfo);
 
+	Free_Grdraster_Ctrl (Ctrl);	/* Deallocate control structure */
+
 	GMT_end (argc, argv);
 	
 	exit (EXIT_SUCCESS);
@@ -533,9 +555,9 @@ int main (int argc, char **argv)
 
 void convert_u_row(struct GRDRASTER_INFO ras, float *row, unsigned char *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
-		tempval = (int)buffer[i];
+		tempval = (GMT_LONG)buffer[i];
 		if (ras.nanset && tempval == ras.nanflag) {
 			row[i] = GMT_f_NaN;
 		}
@@ -550,9 +572,9 @@ void convert_u_row(struct GRDRASTER_INFO ras, float *row, unsigned char *buffer)
 
 void convert_c_row(struct GRDRASTER_INFO ras, float *row, char *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
-		tempval = (int)buffer[i];
+		tempval = (GMT_LONG)buffer[i];
 		if (ras.nanset && tempval == ras.nanflag) {
 			row[i] = GMT_f_NaN;
 		}
@@ -567,7 +589,7 @@ void convert_c_row(struct GRDRASTER_INFO ras, float *row, char *buffer)
 
 void convert_d_row(struct GRDRASTER_INFO ras, float *row, short unsigned int *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
 		if (ras.swap_me) buffer[i] = GMT_swab2 (buffer[i]);
 
@@ -586,7 +608,7 @@ void convert_d_row(struct GRDRASTER_INFO ras, float *row, short unsigned int *bu
 
 void convert_i_row(struct GRDRASTER_INFO ras, float *row, short int *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
 		if (ras.swap_me) buffer[i] = GMT_swab2 (buffer[i]);
 
@@ -605,7 +627,7 @@ void convert_i_row(struct GRDRASTER_INFO ras, float *row, short int *buffer)
 
 void convert_l_row(struct GRDRASTER_INFO ras, float *row, int *buffer)
 {
-	int	i, tempval;
+	GMT_LONG	i, tempval;
 	for (i = 0; i < ras.h.nx; i++) {
 		if (ras.swap_me) buffer[i] = GMT_swab4 (buffer[i]);
 
@@ -622,7 +644,7 @@ void convert_l_row(struct GRDRASTER_INFO ras, float *row, int *buffer)
 	return;
 }
 
-int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
+GMT_LONG	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 {
 	/* Read the file grdraster.info
 		Store the i'th row of the file in rasinfo[i].h.command.
@@ -637,7 +659,7 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 
 	Return 0 if cannot read files correctly, or nrasters if successful.  */
 
-	int	i, j, length, stop_point, nfound = 0;
+	GMT_LONG	i, j, length, stop_point, nfound = 0;
 	size_t	n_alloc;
 	double	global_lon, lon_tol;
 	char	buf[GRD_REMARK_LEN], dir[GRD_REMARK_LEN], *l;
@@ -690,7 +712,7 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		
 		strncpy(buf, &rasinfo[nfound].h.command[i], (size_t)j-i);
 		buf[j-i] = '\0';
-		if ( (sscanf(buf, "%d", &rasinfo[nfound].id) ) != 1) {
+		if ( (sscanf(buf, "%ld", &rasinfo[nfound].id) ) != 1) {
 			fprintf(stderr,"%s: error reading grdraster.info\n", GMT_program);
 			fprintf(stderr,"\tFile number conversion error.\n");
 			return(0);
@@ -776,7 +798,6 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 			return(0);
 		}
 		rasinfo[nfound].geo = (fabs (rasinfo[nfound].h.x_min) > 360.0 || fabs (rasinfo[nfound].h.x_max) > 360.0 || fabs (rasinfo[nfound].h.y_min) > 90.0 || fabs (rasinfo[nfound].h.y_max) > 90.0) ? FALSE : TRUE;
-		GMT->R.processed = FALSE;
 		/* Now find the -I string:  */
 		i = j+1;
 		while (i < length && (rasinfo[nfound].h.command[i] != '-') ) i++;
@@ -915,7 +936,7 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		}
 		else {
 			rasinfo[nfound].nanset = 1;
-			if ( (sscanf(buf, "%d", &rasinfo[nfound].nanflag) ) != 1) {
+			if ( (sscanf(buf, "%ld", &rasinfo[nfound].nanflag) ) != 1) {
 				fprintf(stderr,"%s: error reading grdraster.info\n", GMT_program);
 				fprintf(stderr,"\tNaN flag conversion error.\n");
 				return(0);
@@ -1022,13 +1043,26 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		nfound++;
 		
 		if ((size_t)nfound == n_alloc) {
-			n_alloc += GMT_SMALL_CHUNK;
-			rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, n_alloc, sizeof (struct GRDRASTER_INFO), GMT_program);
+			n_alloc <<= 1;
+			rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, (size_t)n_alloc, sizeof (struct GRDRASTER_INFO), GMT_program);
 		}
 	}
 	fclose (fp);
-	if (nfound > 0) rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, nfound, sizeof (struct GRDRASTER_INFO), GMT_program);
+	if (nfound > 0) rasinfo = (struct GRDRASTER_INFO *) GMT_memory ((void *)rasinfo, (size_t)nfound, sizeof (struct GRDRASTER_INFO), GMT_program);
 	
 	*ras = rasinfo;
 	return (nfound);
 }
+
+void *New_Grdraster_Ctrl () {	/* Allocate and initialize a new control structure */
+	struct GRDRASTER_CTRL *C;
+	
+	C = (struct GRDRASTER_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDRASTER_CTRL), "New_Grdraster_Ctrl");
+	
+	return ((void *)C);
+}
+
+void Free_Grdraster_Ctrl (struct GRDRASTER_CTRL *C) {	/* Deallocate control structure */
+	if (C->G.file) free ((void *)C->G.file);	
+	GMT_free ((void *)C);	
+}
