@@ -1,7 +1,8 @@
 /*--------------------------------------------------------------------
- *    $Id: pscoupe.c,v 1.24 2006/10/11 02:52:17 remko Exp $
+ *    $Id: pscoupe.c,v 1.41 2009/02/07 15:55:18 jluis Exp $
  *
- *    Copyright (c) 1996-2001 by G. Patau
+ *    Copyright (c) 1996-2009 by G. Patau
+ *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -42,7 +43,7 @@ int main (int argc, char **argv)
 
     int     i, j, symbol = 0, n, ix = 0, iy = 1, n_files = 0, fno;
     int     n_args;
-    int     n_rec = 0;
+    GMT_LONG     n_rec = 0;
 
     BOOLEAN    outline = FALSE, p_outline = FALSE, t_outline = FALSE;
     BOOLEAN    error = FALSE, nofile = TRUE, polygon = FALSE;
@@ -85,7 +86,7 @@ int main (int argc, char **argv)
 
     double default_fontsize = 9.0;
     double fontsize = default_fontsize;
-    double default_offset = gmtdefs.measure_unit == 0 ? 0.1 : 0.04;
+    double default_offset = (gmtdefs.measure_unit == GMT_CM ? 0.1 : 0.04);
     double offset = default_offset, angle = 0.0;
     double size = 0.0;
     double tmp1, tmp2, tmp3, tmp4, tmp5;
@@ -220,9 +221,9 @@ int main (int argc, char **argv)
                     if(strstr(argv[i], "/\0") != NULL) {
                         sscanf(strstr(argv[i], "/\0"), "/%lf/%lf",
                            &fontsize, &offset);
-                        if (fontsize == 0.0) fontsize = default_fontsize;
+                        if (GMT_IS_ZERO (fontsize)) fontsize = default_fontsize;
                         if (fontsize < 0.0) no_label = TRUE;
-                        if (offset == 0.0) offset = default_offset;
+                        if (GMT_IS_ZERO (offset)) offset = default_offset;
                         if (argv[i][strlen(argv[i]) - 1] == 'u') justify = 10;
                     }
 
@@ -280,9 +281,9 @@ int main (int argc, char **argv)
                     if(strstr(argv[i], "/\0") != NULL) {
                         sscanf(strstr(argv[i], "/\0"), "/%lf/%lf",
                            &fontsize, &offset);
-                        if (fontsize == 0.0) fontsize = default_fontsize;
+                        if (GMT_IS_ZERO (fontsize)) fontsize = default_fontsize;
                         if (fontsize < 0.0) no_label = TRUE;
-                        if (offset == 0.0) offset = default_offset;
+                        if (GMT_IS_ZERO (offset)) offset = default_offset;
                         if (argv[i][strlen(argv[i]) - 1] == 'u') justify = 10;
                     }
 
@@ -317,7 +318,7 @@ int main (int argc, char **argv)
                                 argv[0], symbol_type);
                         break;
                     }
-                    if (scale == 0.0) {
+                    if (GMT_IS_ZERO (scale)) {
                         read_size = TRUE;
                     }
                     size = scale;
@@ -595,19 +596,17 @@ int main (int argc, char **argv)
         n_files = 1;
     n_args = (argc > 1) ? argc : 2;
     
-    GMT_put_history (argc, argv);   /* Update .gmtcommands4 */
-
     if(frame_coupe) {
         west = 0.;
         east = p_length;
         south = dmin;
         north = dmax;
-        if(PREF.dip == 0.) PREF.dip = 1.;
+        if (GMT_IS_ZERO (PREF.dip)) PREF.dip = 1.0;
     }
 
     greenwich = (project_info.w < 0.0 || project_info.e <= 0.0);
     
-    GMT_map_setup (west, east, south, north);
+    GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
     GMT_plotinit (argc, argv);
     
@@ -629,7 +628,7 @@ int main (int argc, char **argv)
             fp = stdin;
             done = TRUE;
         }
-        else if ((fp = fopen (argv[fno], "r")) == NULL) {
+        else if ((fp = GMT_fopen (argv[fno], "r")) == NULL) {
             fprintf (stderr, "pscoupe: Cannot open file %s\n", argv[fno]);
             continue;
         }
@@ -640,10 +639,10 @@ int main (int argc, char **argv)
             ps_comment (line);
         }
         if (GMT_io.io_header[GMT_IN]) 
-            for (i = 0; i < GMT_io.n_header_recs; i++) fgets (line, BUFSIZ, fp);
+            for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
         
 
-        while (fgets (line, BUFSIZ, fp)) {
+        while (GMT_fgets (line, BUFSIZ, fp)) {
             n_rec++;
             if (read_cmt) {
                 sscanf (line, "%s %s %s %s %s %s %s %s %s %s %s %s %s %[^\n]\n",
@@ -702,7 +701,7 @@ int main (int argc, char **argv)
             }
 
             if (get_rgb) {
-                GMT_get_rgb24 (depth, fill.rgb);
+                GMT_get_rgb_from_z (depth, fill.rgb);
             }
 
             GMT_geo_to_xy (xy[0], xy[1], &plot_x, &plot_y);
@@ -820,7 +819,7 @@ NP2.str, meca.NP2.dip, fault);
                 P.e = atoi(col[12]);
 
 /*
-F. A. Dahlen and Jeoren Trom, Theoretical Seismology, Princeton, 1998, p.167.
+F. A. Dahlen and Jeroen Tromp, Theoretical Seismology, Princeton, 1998, p.167.
 Definition of scalar moment.
 */
                 meca.moment.exponent = T.e;
@@ -858,17 +857,17 @@ Definition of scalar moment.
 
                 moment.exponent = mt.expo;
 /*
-F. A. Dahlen and Jeoren Trom, Theoretical Seismology, Princeton, 1998, p.167.
+F. A. Dahlen and Jeroen Tromp, Theoretical Seismology, Princeton, 1998, p.167.
 Definition of scalar moment.
 */
                 moment.mant = sqrt(squared(mt.f[0]) + squared(mt.f[1]) + squared(mt.f[2]) + 2.*(squared(mt.f[3]) + squared(mt.f[4]) + squared(mt.f[5]))) / M_SQRT2;
                 meca.magms = 0.;
 
 /* normalization by M0 */
-                for(i=0;i<=5;i++) mt.f[i] /= meca.moment.mant;
+                for(i=0;i<=5;i++) mt.f[i] /= moment.mant;
 
                 rot_tensor(mt, PREF, &mtr);
-                momten2axe(mtr, &T, &N, &P);
+                GMT_momten2axe(mtr, &T, &N, &P);
 
                 if(plot_dc || transparence) {
                     axe2dc(T, P, &NP1, &NP2);
@@ -1015,11 +1014,11 @@ Definition of scalar moment.
             }
 
         }
-        if (fp != stdin) fclose (fp);
+        if (fp != stdin) GMT_fclose (fp);
     }
     
     if (gmtdefs.verbose) 
-        fprintf (stderr, "pscoupe: Number of records read: %i\n", n_rec);
+        fprintf (stderr, "pscoupe: Number of records read: %li\n", n_rec);
 
 
     if (skip_if_outside) GMT_map_clip_off ();
